@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import re
 from typing import Union
 from time import sleep
 
@@ -35,7 +36,7 @@ def scale_one_down_up(
 
         try:
             scale_deployment(
-                    name=name, 
+                    name=name,
                     replicas=0,
                     ns=ns,
                     secrets=secrets
@@ -46,29 +47,32 @@ def scale_one_down_up(
             sleep(delay)
 
             scale_deployment(
-                    name=name, 
+                    name=name,
                     replicas=replicas,
                     ns=ns,
                     secrets=secrets
             )
             logger.info(f"Deployment {name} scaled up to {replicas} replicas")
             return replicas
- 
-        except ActivityFailed as err:
-            logger.error(f"Error: not able to scale deployment {name}: {err}")
-            raise Exception(err)
+
+        except Exception as e:
+            logger.error(f"Error: not able to scale deployment {name}: {e}")
+            raise ActivityFailed(
+                "Failed to scale deployment '{s}': {e}".format(s=name, e=str(e)))
 
     else:
-        raise Exception(f"Could not find deployment {name} in {ns}")
+        raise ActivityFailed(f"Could not find deployment {name} in {ns}")
 
 
 def scale_all_down_up(
         context: str = None,
         ns: str = "default",
+        skip: list = [],
         delay: int = 1,
         secrets: Secrets = None):
     """
     for all deployments:
+        Next if name in skip list (deployments to skip).
         Get the number of desired replicas for the deployment name
         Scale deployment down, waits for a delay and then
         scale it up back to the desired replicas
@@ -78,11 +82,13 @@ def scale_all_down_up(
         deployments = api.deployments_for_namespace(ns)
         replicas = dict()
         for name in deployments:
+            if deployment_to_skip(skip, name):
+                continue
             replicas[name] = deployments[name]["DESIRED_REPLICAS"]
             logger.info("Desired replicas for deployment {}: {}".format(name, replicas[name]))
 
             scale_deployment(
-                    name=name, 
+                    name=name,
                     replicas=0,
                     ns=ns,
                     secrets=secrets
@@ -94,14 +100,21 @@ def scale_all_down_up(
 
         for name in deployments:
             scale_deployment(
-                    name=name, 
+                    name=name,
                     replicas=replicas[name],
                     ns=ns,
                     secrets=secrets
             )
             logger.info("Deployment {} scaled up to {} replicas".format(name, replicas[name]))
         return 1
- 
-    except ActivityFailed as err:
-        logger.error("Error: not able to scale namespace {}: {}".format(ns, err))
-        raise Exception(err)
+
+    except Exception as e:
+        logger.error("Error: not able to scale namespace {}: {}".format(ns, str(e)))
+        raise ActivityFailed(
+            "Failed to scale namespace '{ns}': {e}".format(ns=ns, e=str(e)))
+
+def deployment_to_skip(skip: list, name: str):
+    for token in skip:
+        if re.search(token, name):
+            return True
+    return False
